@@ -4,6 +4,7 @@
 
 
 from jarvis import Database, Logger
+import traceback
 
 class Config:
     def __init__(self) -> None:
@@ -21,8 +22,11 @@ class Config:
                     "value": value
                 })
             return True
-        except Exception as e:
-            Logger.e1("config", f"set:{key}", str(e))
+        except Database.Exception:
+            Logger.Logger.e1("config", "set", f"connection refused while setting key {key}, database not running", traceback.format_exc())
+            exit(1)
+        except Exception:
+            Logger.Logger.e1("config", "set", f"unknown error while setting key {key}", traceback.format_exc())
             return False
 
     def get(self, key: str, or_else: any = {}) -> object:
@@ -30,6 +34,9 @@ class Config:
             if self.db.table("config").filter({"key": key}).found:
                 return self.db.table("config").filter({"key": key})[0]
             return or_else 
-        except Exception as e:
-            Logger.e1("config", f"get:{key}", str(e))
-            return False
\ No newline at end of file
+        except Database.Exception:
+            Logger.Logger.e1("config", "get", f"connection refused while getting key {key}, database not running", traceback.format_exc())
+            exit(1)
+        except Exception:
+            Logger.Logger.e1("config", "get", f"unknown error while getting key {key}", traceback.format_exc())
+            return or_else
\ No newline at end of file
