@@ -5,6 +5,13 @@
 class Mime:
     @staticmethod
     def get(filename):
+        try:
+            return Mime._get(filename)
+        except Exception:
+            return "text/html"
+
+    @staticmethod
+    def _get(filename):
         # helper function
         mimes = {
             ".123"			: "application/vnd.lotus-1-2-3",
@@ -759,6 +766,8 @@ class Mime:
             ".wmv"			: "video/x-ms-wmv",
             ".wmx"			: "video/x-ms-wmx",
             ".wmz"			: "application/x-ms-wmz",
+            ".woff"         : "font/woff",
+            ".woff2"         : "font/woff2",
             ".wpd"			: "application/vnd.wordperfect",
             ".wpl"			: "application/vnd.ms-wpl",
             ".wps"			: "application/vnd.ms-works",
